==> cutemaze_1.2.0.orig.tar.gz: cutemaze-1.2.0/translations/cutemaze_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>Board</name>
    <message>
        <source>Sorry</source>
        <translation>Sorry</translation>
    </message>
    <message>
        <source>Unable to load previous game. A new game will be started.</source>
        <translation>Das vorherige Spiel konnte nicht geladen werden. Ein neues Spiel wird gestartet.</translation>
    </message>
    <message>
        <source>%1 elapsed</source>
        <translation>%1 verstrichen</translation>
    </message>
    <message>
        <source>%1 steps taken</source>
        <translation>%1 Schritte genommen</translation>
    </message>
    <message>
        <source>%1 of %2 targets remain</source>
        <translation>%1 von %2 Zielen verbleiben</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Geschafft</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Pausiert</translation>
    </message>
</context>
<context>
    <name>ControlButton</name>
    <message>
        <source>Shift</source>
        <translation>Shift</translation>
    </message>
    <message>
        <source>Ctrl</source>
        <translation>Strg</translation>
    </message>
    <message>
        <source>Meta</source>
        <translation>Meta</translation>
    </message>
    <message>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>Super</source>
        <translation>Super</translation>
    </message>
    <message>
        <source>Windows</source>
        <translation>Windows</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Command</translation>
    </message>
    <message>
        <source>Control</source>
        <translation>Control</translation>
    </message>
    <message>
        <source>Option</source>
        <translation>Optionen</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Wähle eine Sprache</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Systemsprache&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Notiz</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Bitte starte die Anwendung neu damit die Änderungen wirksam werden.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Neues Spiel</translation>
    </message>
    <message>
        <source>Hunt and Kill</source>
        <translation>Jage und Töte</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Recursive Backtracker</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Stapel</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>Stapel 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Stapel 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Stapel 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Stapel 5</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>Algorithmus:</translation>
    </message>
    <message>
        <source>Targets:</source>
        <translation>Ziele:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Größe:</translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <source>Hunt and Kill</source>
        <translation>Jage und Töte</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Recursive Backtracker</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Stapel</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>Stapel 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Stapel 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Stapel 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Stapel 5</translation>
    </message>
</context>
<context>
    <name>Scores</name>
    <message>
        <source>CuteMaze Scores</source>
        <translation>CuteMaze Punkte</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Punkte</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Zeit</translation>
    </message>
    <message>
        <source>Steps</source>
        <translation>Schritte</translation>
    </message>
    <message>
        <source>Algorithm</source>
        <translation>Algorithmen</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Größe</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>Gratulation!</translation>
    </message>
    <message>
        <source>Your score has made the top ten.
Please enter your name:</source>
        <translation>Du hast es in die Top 10 geschafft.
Bitte trege deinen Namen ein:</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Spiel</translation>
    </message>
    <message>
        <source>Show where you&apos;ve been</source>
        <translation>Zeige wo du warst</translation>
    </message>
    <message>
        <source>Show number of steps taken</source>
        <translation>Zeige die Anzahl an genommenen Schritten</translation>
    </message>
    <message>
        <source>Show elapsed time</source>
        <translation>Zeige verstrichene Zeit</translation>
    </message>
    <message>
        <source>Smooth movement</source>
        <translation>sanfte Bewegung</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Steuerung</translation>
    </message>
    <message>
        <source>Move Up:</source>
        <translation>Hoch:</translation>
    </message>
    <message>
        <source>Move Down:</source>
        <translation>Runter:</translation>
    </message>
    <message>
        <source>Move Left:</source>
        <translation>Links:</translation>
    </message>
    <message>
        <source>Move Right:</source>
        <translation>Rechts:</translation>
    </message>
    <message>
        <source>Toggle Flag:</source>
        <translation>Toggle Flagge</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>Themes</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <source>Select Theme File</source>
        <translation>Wähle Theme</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Sorry</translation>
    </message>
    <message>
        <source>Unable to create data folder.</source>
        <translation>Konnte keinen Data Ordner erstellen.</translation>
    </message>
    <message>
        <source>Unable to copy theme file.</source>
        <translation>Konnte die Theme Datei nicht kopieren.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Frage</translation>
    </message>
    <message>
        <source>Remove the selected theme?</source>
        <translation>Das gewählte Theme entfernen?</translation>
    </message>
    <message>
        <source>Unable to remove the selected theme.</source>
        <translation>Kann das gewählte Theme nicht entfernen.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>CuteMaze</source>
        <translation>CuteMaze</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ansicht</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Strg++</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Strg+-</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Über &amp;Qt</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Spiel</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Neu</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pause</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;Tipp</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation>High &amp;Scores</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>Zoom &amp;Rein</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>Zoom &amp;Raus</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Einstellungen</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Programm &amp;Sprache</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Voreinstellungen</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Über</translation>
    </message>
    <message>
        <source>A top-down maze game</source>
        <translation>Ein Top-Down Labyrinth Spiel</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2007-%1 Graeme Gott</source>
        <translation>copyright &amp;cop; 2007-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Veröffentlicht unter der &lt;a href=%1&gt;GPL 3&lt;/a&gt; Lizenz</translation>
    </message>
    <message>
        <source>Icons are from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; theme</source>
        <translation>Icons entstammen dem &lt;a href=%1&gt;Oxygen&lt;/a&gt; Theme</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Unter der &lt;a href=%1&gt;LGPL 3&lt;/a&gt; Lizenz genutzt</translation>
    </message>
</context>
</TS>

==> cutemaze_1.2.6.orig.tar.gz: cutemaze-1.2.6/translations/cutemaze_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>Board</name>
    <message>
        <source>Sorry</source>
        <translation>Sorry</translation>
    </message>
    <message>
        <source>Unable to load previous game. A new game will be started.</source>
        <translation>Das vorherige Spiel konnte nicht geladen werden. Ein neues Spiel wird gestartet.</translation>
    </message>
    <message>
        <source>%1 elapsed</source>
        <translation>%1 verstrichen</translation>
    </message>
    <message>
        <source>%1 steps taken</source>
        <translation>%1 Schritte genommen</translation>
    </message>
    <message>
        <source>%1 of %2 targets remain</source>
        <translation>%1 von %2 Zielen verbleiben</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Geschafft</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Pausiert</translation>
    </message>
</context>
<context>
    <name>ControlButton</name>
    <message>
        <source>Shift</source>
        <translation>Shift</translation>
    </message>
    <message>
        <source>Ctrl</source>
        <translation>Strg</translation>
    </message>
    <message>
        <source>Meta</source>
        <translation>Meta</translation>
    </message>
    <message>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>Super</source>
        <translation>Super</translation>
    </message>
    <message>
        <source>Windows</source>
        <translation>Windows</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Command</translation>
    </message>
    <message>
        <source>Control</source>
        <translation>Control</translation>
    </message>
    <message>
        <source>Option</source>
        <translation>Optionen</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Sprache wählen:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Systemsprache&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Hinweis</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Bitte starten Sie die Anwendung neu, damit die Änderungen wirksam werden.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Neues Spiel</translation>
    </message>
    <message>
        <source>Hunt and Kill</source>
        <translation>Jage und Töte</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Recursive Backtracker</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Stapel</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>Stapel 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Stapel 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Stapel 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Stapel 5</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>Algorithmus:</translation>
    </message>
    <message>
        <source>Targets:</source>
        <translation>Ziele:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Größe:</translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <source>Hunt and Kill</source>
        <translation>Jage und Töte</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Recursive Backtracker</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Stapel</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>Stapel 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Stapel 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Stapel 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Stapel 5</translation>
    </message>
</context>
<context>
    <name>Scores</name>
    <message>
        <source>CuteMaze Scores</source>
        <translation>CuteMaze Punkte</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Punkte</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Zeit</translation>
    </message>
    <message>
        <source>Steps</source>
        <translation>Schritte</translation>
    </message>
    <message>
        <source>Algorithm</source>
        <translation>Algorithmus</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Größe</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>Gratulation!</translation>
    </message>
    <message>
        <source>Your score has made the top ten.
Please enter your name:</source>
        <translation>Du hast es in die Top 10 geschafft.
Bitte trage deinen Namen ein:</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Spiel</translation>
    </message>
    <message>
        <source>Show where you&apos;ve been</source>
        <translation>Zeige wo du warst</translation>
    </message>
    <message>
        <source>Show number of steps taken</source>
        <translation>Zeige die Anzahl an genommenen Schritten</translation>
    </message>
    <message>
        <source>Show elapsed time</source>
        <translation>Zeige verstrichene Zeit</translation>
    </message>
    <message>
        <source>Smooth movement</source>
        <translation>Sanfte Bewegung</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Steuerung</translation>
    </message>
    <message>
        <source>Move Up:</source>
        <translation>Hoch:</translation>
    </message>
    <message>
        <source>Move Down:</source>
        <translation>Runter:</translation>
    </message>
    <message>
        <source>Move Left:</source>
        <translation>Links:</translation>
    </message>
    <message>
        <source>Move Right:</source>
        <translation>Rechts:</translation>
    </message>
    <message>
        <source>Toggle Flag:</source>
        <translation>Toggle Flagge</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>Themes</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <source>Select Theme File</source>
        <translation>Theme-Datei wählen</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Sorry</translation>
    </message>
    <message>
        <source>Unable to create data folder.</source>
        <translation>Konnte keinen Data Ordner erstellen.</translation>
    </message>
    <message>
        <source>Unable to copy theme file.</source>
        <translation>Konnte die Theme Datei nicht kopieren.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Frage</translation>
    </message>
    <message>
        <source>Remove the selected theme?</source>
        <translation>Das gewählte Theme entfernen?</translation>
    </message>
    <message>
        <source>Unable to remove the selected theme.</source>
        <translation>Kann das gewählte Theme nicht entfernen.</translation>
    </message>
    <message>
        <source>Show Hint:</source>
        <translation>Hinweis anzeigen:</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>CuteMaze</source>
        <translation>CuteMaze</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ansicht</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Strg++</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Strg+-</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Über &amp;Qt</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Spiel</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Neu</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pause</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;Tipp</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation>High &amp;Scores</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>Zoom &amp;Rein</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>Zoom &amp;Raus</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Einstellungen</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Programm&amp;sprache</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Voreinstellungen</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Über</translation>
    </message>
    <message>
        <source>A top-down maze game</source>
        <translation>Ein Top-Down Labyrinth Spiel</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2007-%1 Graeme Gott</source>
        <translation>copyright &amp;cop; 2007-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Veröffentlicht unter der &lt;a href=%1&gt;GPL 3&lt;/a&gt;-Lizenz</translation>
    </message>
    <message>
        <source>Icons are from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; theme</source>
        <translation>Icons entstammen dem &lt;a href=%1&gt;Oxygen&lt;/a&gt;-Theme</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Unter der &lt;a href=%1&gt;LGPL 3&lt;/a&gt; Lizenz genutzt</translation>
    </message>
</context>
</TS>
